Bottleneck 0.8.0
================

*Release date: 2014-01-21*

This version of Bottleneck requires NumPy 1.8.

Breaks from 0.7.0
~~~~~~~~~~~~~~~~~

- This version of Bottleneck requires NumPy 1.8
- nanargmin and nanargmax behave like the corresponding functions in NumPy 1.8

Bug fixes
~~~~~~~~~

- nanargmax/nanargmin wrong for redundant max/min values in 1d int arrays

Contributors
~~~~~~~~~~~~

.. contributors:: v0.7.0..v0.8.0
